@@ -5,19 +5,20 @@ from .common import *
 
 # set final parameters values to use for exectuing commands -
 # istack.action_parameters and istack.r_parameters
-def _set_action_parameters(istack, params_default, params_changed,
-                           params_added, params_forced_default):
+def _set_action_parameters(
+    istack, params_default, params_changed, params_added, params_forced_default
+):
     for key in sorted(istack.parameters):
         v = istack.parameters[key]
 
         try:
-            default_value = v['Default']
+            default_value = v["Default"]
         except Exception:
             default_value = None
         use_previous_value = False
 
         # get list of AllowedValues
-        allowed_values = v['AllowedValues'] if 'AllowedValues' in v else []
+        allowed_values = v["AllowedValues"] if "AllowedValues" in v else []
 
         # check if key exist as istack.cfg param/attr too
         try:
@@ -34,19 +35,17 @@ def _set_action_parameters(istack, params_default, params_changed,
             if in_cfg and current_value != cfg_value:
                 # get value from specified cmd arg
                 value = cfg_value
-                params_changed[key] = f'{current_value} => {value}'
+                params_changed[key] = f"{current_value} => {value}"
 
             # current value is not allowed by new template
-            elif len(allowed_values) > 0 and (
-                    current_value not in allowed_values):
+            elif len(allowed_values) > 0 and (current_value not in allowed_values):
                 # get value from template default
                 value = default_value
-                params_forced_default[key] = (
-                    f'{current_value} => {default_value}')
+                params_forced_default[key] = f"{current_value} => {default_value}"
 
             # current value is unchanged and allowed
             else:
-                value = ''
+                value = ""
                 use_previous_value = True
                 params_default[key] = current_value
 
@@ -68,31 +67,28 @@ def _set_action_parameters(istack, params_default, params_changed,
         # append dictionary element to list
         istack.action_parameters.append(
             {
-                'ParameterKey': key,
-                'ParameterValue': value,
-                'UsePreviousValue': use_previous_value,
-            } if istack.stack else
-            {
-                'ParameterKey': key,
-                'ParameterValue': value,
+                "ParameterKey": key,
+                "ParameterValue": str(value),
+                "UsePreviousValue": use_previous_value,
             }
+            if istack.stack
+            else {"ParameterKey": key, "ParameterValue": str(value),}
         )
 
         # update resolved parameter final value istack.r_parameters
-        istack.r_parameters[key] = (current_value
-                                    if use_previous_value else value)
+        istack.r_parameters[key] = current_value if use_previous_value else value
 
 
 # force EnvShort param value based on Env one
 def _force_envshort(istack):
     # use arg if exist or use current value
-    env = istack.cfg.Env if istack.cfg.Env else istack.c_parameters['Env']
+    env = istack.cfg.Env if istack.cfg.Env else istack.c_parameters["Env"]
 
     env_envshort_dict = {
-        'dev': 'dev',
-        'stg': 'stg',
-        'prd': 'prd',
-        'prod': 'prd',
+        "dev": "dev",
+        "stg": "stg",
+        "prd": "prd",
+        "prod": "prd",
     }
 
     istack.cfg.EnvShort = env_envshort_dict[env]
@@ -105,17 +101,18 @@ def _force_envshort(istack):
 # /ibox/master-2ed25d5/templates/cache-portal.json
 def _do_envstackversion_from_s3_template(istack):
     template = istack.cfg.template
-    istack.cfg.version = template.split("/")[4] if str(
-        template).startswith('https') else '1'
+    istack.cfg.version = (
+        template.split("/")[4] if str(template).startswith("https") else "1"
+    )
     istack.cfg.EnvStackVersion = istack.cfg.version
 
 
 def get_stack_parameter_parser(istack):
     parser = argparse.ArgumentParser(
-        description='',
+        description="",
         add_help=False,
         allow_abbrev=False,
-        usage='Allowed Stack Params ... allowed values are in {}',
+        usage="Allowed Stack Params ... allowed values are in {}",
         formatter_class=argparse.RawTextHelpFormatter,
     )
 
@@ -123,28 +120,25 @@ def get_stack_parameter_parser(istack):
     #    stack_parameters, key=lambda x: x['ParameterKey']):
     for p in sorted(istack.parameters):
         v = istack.parameters[p]
-        allowed_values = v['AllowedValues'] if 'AllowedValues' in v else []
-        kwargs = {'type': str, 'metavar': '\t%s' % v['Description']}
+        allowed_values = v["AllowedValues"] if "AllowedValues" in v else []
+        kwargs = {"type": str, "metavar": "\t%s" % v["Description"]}
 
         # If Parameter do not have Default value and is new or
         # current value is not allowed in new template,
         # enforce it as required
-        if 'Default' not in v and (
-                p not in istack.c_parameters or (
-                    allowed_values and
-                    istack.c_parameters[p] not in allowed_values)):
-            kwargs['required'] = True
+        if "Default" not in v and (
+            p not in istack.c_parameters
+            or (allowed_values and istack.c_parameters[p] not in allowed_values)
+        ):
+            kwargs["required"] = True
 
         if len(allowed_values) > 0:
-            kwargs['choices'] = allowed_values
-            kwargs['help'] = '{%s}\n\n' % ', '.join(allowed_values)
+            kwargs["choices"] = allowed_values
+            kwargs["help"] = "{%s}\n\n" % ", ".join(allowed_values)
         else:
-            kwargs['help'] = '\n'
+            kwargs["help"] = "\n"
 
-        parser.add_argument(
-            '--%s' % p,
-            **kwargs
-        )
+        parser.add_argument("--%s" % p, **kwargs)
 
     return parser
 
@@ -160,31 +154,24 @@ def add_stack_params_as_args(istack, parser):
 
 def show_override(istack):
     params = {}
-
-    template_parameters = istack.client.get_template_summary(
-        StackName=istack.name)['Parameters']
-
-    for p in istack.stack.parameters:
-        name = p['ParameterKey']
-        value = p['ParameterValue']
+    for name, value in istack.c_parameters.items():
         if (
-            not name.startswith('Env')
-            and any(name not in n for n in ['UpdateMode'])
+            not name.startswith("Env")
+            and any(name not in n for n in ["UpdateMode"])
             and any(
-                name == s['ParameterKey']
-                and (value != s['DefaultValue'] if 'DefaultValue' in s else '')
-                for s in template_parameters
+                name == t_name and (value != t_value.get("Default"))
+                for t_name, t_value in istack.parameters.items()
             )
         ):
             params[name] = value
 
     out = pformat(params, width=istack.cfg.OUT_WIDTH)
 
-    istack.mylog(f'CURRENT NOT DEFAULT - STACK PARAMETERS\n{out}\n')
+    istack.mylog(f"CURRENT NOT DEFAULT - STACK PARAMETERS\n{out}\n")
 
 
 def process(istack, show=True):
-    logger.info('Processing Parameters')
+    logger.info("Processing Parameters")
 
     # get stack parameter parser
     parser = get_stack_parameter_parser(istack)
@@ -193,7 +180,7 @@ def process(istack, show=True):
     add_stack_params_as_args(istack, parser)
 
     # if template include EnvShort params force its value based on the Env one
-    if 'EnvShort' in istack.parameters:
+    if "EnvShort" in istack.parameters:
         _force_envshort(istack)
 
     # if using template option set/force EnvStackVersion
@@ -223,43 +210,51 @@ def process(istack, show=True):
 
     # set final parameters values to use for exectuing action -
     # istack.action_parameters and istack.r_parameters
-    _set_action_parameters(istack, params_default, params_changed,
-                           params_added, params_forced_default)
+    _set_action_parameters(
+        istack, params_default, params_changed, params_added, params_forced_default
+    )
 
     if not show:
         return
 
     # show changes to output
-    print('\n')
+    print("\n")
     # disabled for now - it make no sense to display them
     # if not istack.stack and params_default:
     #     print('DEFAULT - STACK PARAMETERS\n%s\n' % pformat(
     #         params_default, width=1000000))
 
     if params_changed:
-        istack.mylog('CHANGED - STACK PARAMETERS\n%s\n' % pformat(
-            params_changed, width=1000000))
+        istack.mylog(
+            "CHANGED - STACK PARAMETERS\n%s\n" % pformat(params_changed, width=1000000)
+        )
 
     if istack.stack and params_added:
-        istack.mylog('ADDED - STACK PARAMETERS\n%s\n' % pformat(
-            params_added, width=1000000))
+        istack.mylog(
+            "ADDED - STACK PARAMETERS\n%s\n" % pformat(params_added, width=1000000)
+        )
 
     if params_forced_default:
-        istack.mylog('FORCED TO DEFAULT - STACK PARAMETERS\n%s\n' % pformat(
-            params_forced_default, width=1000000))
+        istack.mylog(
+            "FORCED TO DEFAULT - STACK PARAMETERS\n%s\n"
+            % pformat(params_forced_default, width=1000000)
+        )
 
 
 def get(stack):
     try:
-        s_parameters = stack['Parameters']
+        s_parameters = stack["Parameters"]
     except Exception as e:
         pass
     else:
         parameters = {}
         for parameter in s_parameters:
-            key = parameter['ParameterKey']
-            value = parameter.get(
-                'ResolvedValue', parameter.get('ParameterValue'))
+            key = parameter["ParameterKey"]
+            # Think is better to use always value not the resolved one,
+            # or i will have problem later when i check if value is allowed
+            # value = parameter.get(
+            #     'ResolvedValue', parameter.get('ParameterValue'))
+            value = parameter.get("ParameterValue")
             parameters[key] = value
 
         return parameters
