@@ -4,41 +4,42 @@ from .common import *
 
 
 def _process_template(istack):
-
     def _recursive_resolve(name, value):
         if isinstance(value, (dict, OrderedDict)):
             r_root = {}
             for r, v in value.items():
-                if r == 'Fn::If':
+                if r == "Fn::If":
                     return _resolve_if(name, v)
-                elif r == 'Ref':
+                elif r == "Ref":
                     return _resolve_ref(name, v)
-                elif r == 'Fn::GetAtt':
-                    return '!GetAtt %s.%s' % (v[0], v[1])
-                elif r == 'Fn::GetAZs':
-                    return '!GetAZs %s' % istack.boto3.region_name
-                elif r == 'Fn::ImportValue':
+                elif r == "Fn::GetAtt":
+                    return "!GetAtt %s.%s" % (v[0], v[1])
+                elif r == "Fn::GetAZs":
+                    return "!GetAZs %s" % istack.boto3.region_name
+                elif r == "Fn::ImportValue":
                     return _resolve_import(name, v)
-                elif r == 'Fn::Sub':
+                elif r == "Fn::Sub":
                     return _resolve_sub(name, v)
-                elif r == 'Fn::FindInMap':
+                elif r == "Fn::FindInMap":
                     return _resolve_findinmap(name, v)
-                elif r == 'Fn::Join':
+                elif r == "Fn::Join":
                     return _resolve_join(name, v)
-                elif r == 'Fn::Select':
+                elif r == "Fn::Select":
                     return _resolve_select(name, v)
-                elif r == 'Fn::Split':
+                elif r == "Fn::Split":
                     return _resolve_split(name, v)
-                elif r == 'Fn::Or':
+                elif r == "Fn::Or":
                     return _resolve_or(name, v)
-                elif r == 'Fn::And':
+                elif r == "Fn::And":
                     return _resolve_and(name, v)
-                elif r == 'Fn::Equals':
+                elif r == "Fn::Equals":
                     return _resolve_equals(name, v)
-                elif r == 'Fn::Not':
+                elif r == "Fn::Not":
                     return _resolve_not(name, v)
-                elif r == 'Condition' and isinstance(v, str):
+                elif r == "Condition" and isinstance(v, str):
                     return _resolve_condition(name, v)
+                elif r == "Fn::Base64":
+                    return _recursive_resolve(name, v)
                 else:
                     r_value = _recursive_resolve(name, v)
 
@@ -67,33 +68,32 @@ def _process_template(istack):
             sub_data = value[1]
         else:
             sub_string = value
-            sub_data = ''
+            sub_data = ""
 
         while True:
-            found = sub_string.find('${')
+            found = sub_string.find("${")
             if found == -1:
                 break
             find_start = found + 2
-            find_end = sub_string[find_start:].find('}') + find_start
+            find_end = sub_string[find_start:].find("}") + find_start
             key = sub_string[find_start:find_end]
-            replace_from = '${' + key + '}'
+            replace_from = "${" + key + "}"
 
             if key in sub_data:
                 r_value = _recursive_resolve(key, sub_data[key])
                 replace_to = r_value
             elif key in istack.r_parameters:
                 replace_to = istack.r_parameters[key]
-            elif key == 'AWS::Region':
+            elif key == "AWS::Region":
                 replace_to = istack.boto3.region_name
-            elif key == 'AWS::AccountId':
-                replace_to = istack.boto3.client(
-                    'sts').get_caller_identity()['Account']
+            elif key == "AWS::AccountId":
+                replace_to = istack.boto3.client("sts").get_caller_identity()["Account"]
             else:
                 replace_to = key
 
             sub_string = sub_string.replace(replace_from, str(replace_to))
 
-        if sub_string.startswith('https://'):
+        if sub_string.startswith("https://"):
             _find_s3_files(name, sub_string)
 
         return sub_string
@@ -104,13 +104,13 @@ def _process_template(istack):
         return _recursive_resolve(name, value)
 
     def _resolve_ref(name, v):
-        if v == 'AWS::Region':
+        if v == "AWS::Region":
             value = istack.boto3.region_name
         elif v in istack.r_parameters:
             value = istack.r_parameters[v]
         else:
             # value = {'Ref': v}
-            value = f'!Ref {v}'
+            value = f"!Ref {v}"
 
         return value
 
@@ -134,11 +134,10 @@ def _process_template(istack):
         return str(istack.mappings[mapname][key][key_value])
 
     def _resolve_join(name, v):
-        j_list = []
-        for n in v[1]:
-            j_list.append(str(_recursive_resolve(name, n)))
+        sep = v[0]
+        data = v[1]
 
-        return v[0].join(j_list)
+        return sep.join(map(str, _recursive_resolve(name, data)))
 
     def _resolve_select(name, v):
         index = v[0]
@@ -188,25 +187,26 @@ def _process_template(istack):
         return istack.r_conditions[v]
 
     def _awsnovalue(value):
-        if value == 'AWS::NoValue' or value == '!Ref AWS::NoValue':
+        if value == "AWS::NoValue" or value == "!Ref AWS::NoValue":
             return True
 
         return False
 
     def _find_s3_files(name, sub_string):
-        if ('AWS::AutoScaling::LaunchConfiguration' in istack.t_resources and
-                istack.t_resources[
-                    'AWS::AutoScaling::LaunchConfiguration'] == name):
-            data = sub_string[8:].partition('/')
+        if (
+            "AWS::AutoScaling::LaunchConfiguration" in istack.t_resources
+            and istack.t_resources["AWS::AutoScaling::LaunchConfiguration"] == name
+        ):
+            data = sub_string[8:].partition("/")
             host = data[0]
-            if not host.endswith('amazonaws.com'):
+            if not host.endswith("amazonaws.com"):
                 return
             key = data[2]
-            s_bucket = host.rsplit('.', 3)
-            if s_bucket[1].startswith('s3-'):
+            s_bucket = host.rsplit(".", 3)
+            if s_bucket[1].startswith("s3-"):
                 bucket = s_bucket[0]
             else:
-                bucket = host[:host.rfind('.s3.')]
+                bucket = host[: host.rfind(".s3.")]
 
             if host == bucket:
                 return
@@ -215,8 +215,8 @@ def _process_template(istack):
 
     def _check_lambda(r):
         try:
-            bucket = istack.r_resources[r]['Properties']['Code']['S3Bucket']
-            key = istack.r_resources[r]['Properties']['Code']['S3Key']
+            bucket = istack.r_resources[r]["Properties"]["Code"]["S3Bucket"]
+            key = istack.r_resources[r]["Properties"]["Code"]["S3Key"]
         except Exception:
             pass
         else:
@@ -236,16 +236,15 @@ def _process_template(istack):
 
         for r in sorted(istack.resources):
             v = istack.resources[r]
-            if not ('Condition' in v
-                    and not istack.r_conditions[v['Condition']]):
+            if not ("Condition" in v and not istack.r_conditions[v["Condition"]]):
                 try:
-                    del v['Condition']
+                    del v["Condition"]
                 except Exception:
                     pass
-                istack.t_resources[v['Type']] = r
+                istack.t_resources[v["Type"]] = r
                 istack.r_resources[r] = _recursive_resolve(r, v)
 
-                if v['Type'] == 'AWS::Lambda::Function':
+                if v["Type"] == "AWS::Lambda::Function":
                     _check_lambda(r)
 
     _process_conditions()
@@ -259,35 +258,31 @@ def _check_s3_files(istack):
         try:
             istack.s3.head_object(Bucket=bucket, Key=key)
         except botocore.exceptions.ClientError as e:
-            logger.error(f'Missing: {bucket}/{key}')
+            logger.error(f"Missing: {bucket}/{key}")
             raise IboxError(e)
 
 
 def _check_ecr_images(istack):
-    name = istack.t_resources['AWS::ECS::TaskDefinition']
+    name = istack.t_resources["AWS::ECS::TaskDefinition"]
     images = []
-    ecr = istack.boto3.client('ecr')
+    ecr = istack.boto3.client("ecr")
 
-    for c in (istack.r_resources[name]
-              ['Properties']['ContainerDefinitions']):
-        image = c['Image']
-        registry_id = image[0:image.find('.')]
-        repository_name = image[image.find('/')+1:image.find(':')]
-        image_id = image[image.find(':') + 1:]
+    for c in istack.r_resources[name]["Properties"]["ContainerDefinitions"]:
+        image = c["Image"]
+        registry_id = image[0 : image.find(".")]
+        repository_name = image[image.find("/") + 1 : image.find(":")]
+        image_id = image[image.find(":") + 1 :]
         # Skip already processed images and images from public docker repo
-        if (image not in images and
-                '.dkr.ecr.' in image):
+        if image not in images and ".dkr.ecr." in image:
             try:
                 ecr.describe_images(
                     registryId=registry_id,
                     repositoryName=repository_name,
-                    imageIds=[{
-                        'imageTag': image_id,
-                    }],
+                    imageIds=[{"imageTag": image_id,}],
                 )
                 images.append(image)
             except botocore.exceptions.ClientError as e:
-                logger.error(f'Missing: {image}')
+                logger.error(f"Missing: {image}")
                 raise IboxError(e)
 
 
@@ -295,19 +290,19 @@ def _do_check(istack):
     if istack.s3_files:
         _check_s3_files(istack)
 
-    if 'AWS::ECS::TaskDefinition' in istack.t_resources:
+    if "AWS::ECS::TaskDefinition" in istack.t_resources:
         _check_ecr_images(istack)
 
 
 def show(istack):
     _process_template(istack)
-    print('')
-    logger.info(f'Resolved: {istack.name}')
+    print("")
+    logger.info(f"Resolved: {istack.name}")
     print(yaml.dump(istack.r_resources))
 
 
 def process(istack):
-    logger.debug('Processing Template')
+    logger.debug("Processing Template")
 
     try:
         _process_template(istack)
@@ -316,5 +311,7 @@ def process(istack):
         raise
     except Exception as e:
         pprint(e)
-        logger.warning('Error resolving template. '
-                       'Will not be able to validate s3 files and ecr images.')
+        logger.warning(
+            "Error resolving template. "
+            "Will not be able to validate s3 files and ecr images."
+        )
